@@ -6,7 +6,7 @@ import (
 	"os"
 
 	tea "github.com/charmbracelet/bubbletea"
-	"github.com/getkin/kin-openapi/openapi3"
+	"github.com/pb33f/libopenapi"
 )
 
 func main() {
@@ -27,24 +27,19 @@ func main() {
 		}
 	}
 
-	loader := openapi3.NewLoader()
-	// Enable validation for both OpenAPI 3.0 and 3.1
-	loader.IsExternalRefsAllowed = true
-
-	doc, err := loader.LoadFromData(content)
+	document, err := libopenapi.NewDocument(content)
 	if err != nil {
-		fmt.Fprintf(os.Stderr, "Error parsing OpenAPI: %v\n", err)
+		fmt.Fprintf(os.Stderr, "Error creating document: %v\n", err)
 		os.Exit(1)
 	}
 
-	// Validate the document - this works for both 3.0 and 3.1
-	err = doc.Validate(loader.Context)
+	v3Model, err := document.BuildV3Model()
 	if err != nil {
-		fmt.Fprintf(os.Stderr, "OpenAPI validation error: %v\n", err)
+		fmt.Fprintf(os.Stderr, "Error building V3 model: %v\n", err)
 		os.Exit(1)
 	}
 
-	m := NewModel(doc)
+	m := NewModel(&v3Model.Model)
 	p := tea.NewProgram(m, tea.WithAltScreen())
 
 	if _, err := p.Run(); err != nil {
